@@ -1,6 +1,8 @@
 
 # Function to check that credMass is sane
 checkCredMass <- function(x)  {
-  if(is.na(x) || length(x) != 1 || x <= 0 || x >= 1)
+  if(length(x) != 1)
+    stop("credMass must be a single value")
+  if(is.na(x) || x <= 0 || x >= 1)
     stop("credMass must be between 0 and 1")
 }
